==> tiltfive_sdk_1.3.3.tar.xz: tiltfive_sdk_1.3.3/Native/docs/html/a00030.js <==
var a00030 =
[
    [ "tiltfive::Error", "a00030.html#ga6debabd18fea86dba1be4fbb79687162", [
      [ "tiltfive::Error::kSuccess", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a8c632159fa131f09d04f94e3cbcd8782", null ],
      [ "tiltfive::Error::kTimeout", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a7f27861ff1d3f550c6aa77150d7edabd", null ],
      [ "tiltfive::Error::kNoContext", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a4af3e86ee3e90efd831111dedd583a8d", null ],
      [ "tiltfive::Error::kLibraryUnavailable", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a2325339cb0be773a12f307584010c26f", null ],
      [ "tiltfive::Error::kInternalError", "a00030.html#gga6debabd18fea86dba1be4fbb79687162afcd417a134c251034b0d61b07c826394", null ],
      [ "tiltfive::Error::kNoService", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a9fe28a8934d875dd6b0219778fe25620", null ],
      [ "tiltfive::Error::kIoFailure", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a9356497aac0421643b49d8eeb0a79e97", null ],
      [ "tiltfive::Error::kRequestIdUnknown", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a033308e7e691dce5cd462a1c067de7f9", null ],
      [ "tiltfive::Error::kInvalidArgument", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a80fdc050363ea6925fa2e7eb7f0a94a0", null ],
      [ "tiltfive::Error::kDeviceLost", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a5d6852f310025070aaf39f40f14c76e6", null ],
      [ "tiltfive::Error::kTargetNotFound", "a00030.html#gga6debabd18fea86dba1be4fbb79687162aeeddc1f26855058c320f192eeea38385", null ],
      [ "tiltfive::Error::kInvalidState", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a9a0c175e3c2f23590fa82da619a788b4", null ],
      [ "tiltfive::Error::kSettingUnknown", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a4281328af49b454e7b3612ddbae52c84", null ],
      [ "tiltfive::Error::kSettingWrongType", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a2265b16aa023150bd9afd4605e061bc8", null ],
      [ "tiltfive::Error::kMiscRemote", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a98f5b1ac1c73bf20c8a88a302cb25bbe", null ],
      [ "tiltfive::Error::kOverflow", "a00030.html#gga6debabd18fea86dba1be4fbb79687162aae5484a6f25ec42ff2fc33b0fc8bc2d5", null ],
      [ "tiltfive::Error::kGfxApiUnavailable", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a310488b448f6bfb7a79ef1759c337b6d", null ],
      [ "tiltfive::Error::kUnsupported", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a8554ab1ea5f616650e23048f5b7aef43", null ],
      [ "tiltfive::Error::kDecodeError", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a535b0396b0d994c5676b3d943ed4a0a1", null ],
      [ "tiltfive::Error::kInvalidGfxContext", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a64ee3b0ac0474808b563b49088d87fff", null ],
      [ "tiltfive::Error::kGfxContextInitFail", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a4f3af70353379fa8ea9fecd37cae7faf", null ],
      [ "tiltfive::Error::kTryAgain", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a2c50ce0d3fcf5b0d53da397ed981a9a9", null ],
      [ "tiltfive::Error::kUnavailable", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a8a1714a85ad21a1c4814b260d2cd24dd", null ],
      [ "tiltfive::Error::kAlreadyConnected", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a24b0774645da8e1ae47649ae64ca88ea", null ],
      [ "tiltfive::Error::kNotConnected", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a32a54fa8629fe6e9cb3e265e959258d8", null ],
      [ "tiltfive::Error::kStringOverflow", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a06d34bffca9582c3dbc11cdea43e5be7", null ],
      [ "tiltfive::Error::kServiceIncompatible", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a1ff7b6aeb3db444a14dae140348e5a25", null ],
      [ "tiltfive::Error::kPermissionDenied", "a00030.html#gga6debabd18fea86dba1be4fbb79687162adc0b458db7d0dd510aae0367dfafc4af", null ],
      [ "tiltfive::Error::kInvalidBuffer", "a00030.html#gga6debabd18fea86dba1be4fbb79687162ac63eb897493f14bd808056306dc2a845", null ]
    ] ]
];

==> tiltfive_sdk_1.4.0.tar.xz: tiltfive_sdk_1.4.0/Native/docs/html/a00030.js <==
var a00030 =
[
    [ "tiltfive::Error", "a00030.html#ga6debabd18fea86dba1be4fbb79687162", [
      [ "tiltfive::Error::kSuccess", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a8c632159fa131f09d04f94e3cbcd8782", null ],
      [ "tiltfive::Error::kTimeout", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a7f27861ff1d3f550c6aa77150d7edabd", null ],
      [ "tiltfive::Error::kNoContext", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a4af3e86ee3e90efd831111dedd583a8d", null ],
      [ "tiltfive::Error::kLibraryUnavailable", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a2325339cb0be773a12f307584010c26f", null ],
      [ "tiltfive::Error::kInternalError", "a00030.html#gga6debabd18fea86dba1be4fbb79687162afcd417a134c251034b0d61b07c826394", null ],
      [ "tiltfive::Error::kNoService", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a9fe28a8934d875dd6b0219778fe25620", null ],
      [ "tiltfive::Error::kIoFailure", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a9356497aac0421643b49d8eeb0a79e97", null ],
      [ "tiltfive::Error::kRequestIdUnknown", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a033308e7e691dce5cd462a1c067de7f9", null ],
      [ "tiltfive::Error::kInvalidArgument", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a80fdc050363ea6925fa2e7eb7f0a94a0", null ],
      [ "tiltfive::Error::kDeviceLost", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a5d6852f310025070aaf39f40f14c76e6", null ],
      [ "tiltfive::Error::kTargetNotFound", "a00030.html#gga6debabd18fea86dba1be4fbb79687162aeeddc1f26855058c320f192eeea38385", null ],
      [ "tiltfive::Error::kInvalidState", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a9a0c175e3c2f23590fa82da619a788b4", null ],
      [ "tiltfive::Error::kSettingUnknown", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a4281328af49b454e7b3612ddbae52c84", null ],
      [ "tiltfive::Error::kSettingWrongType", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a2265b16aa023150bd9afd4605e061bc8", null ],
      [ "tiltfive::Error::kMiscRemote", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a98f5b1ac1c73bf20c8a88a302cb25bbe", null ],
      [ "tiltfive::Error::kOverflow", "a00030.html#gga6debabd18fea86dba1be4fbb79687162aae5484a6f25ec42ff2fc33b0fc8bc2d5", null ],
      [ "tiltfive::Error::kGfxApiUnavailable", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a310488b448f6bfb7a79ef1759c337b6d", null ],
      [ "tiltfive::Error::kUnsupported", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a8554ab1ea5f616650e23048f5b7aef43", null ],
      [ "tiltfive::Error::kDecodeError", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a535b0396b0d994c5676b3d943ed4a0a1", null ],
      [ "tiltfive::Error::kInvalidGfxContext", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a64ee3b0ac0474808b563b49088d87fff", null ],
      [ "tiltfive::Error::kGfxContextInitFail", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a4f3af70353379fa8ea9fecd37cae7faf", null ],
      [ "tiltfive::Error::kTryAgain", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a2c50ce0d3fcf5b0d53da397ed981a9a9", null ],
      [ "tiltfive::Error::kUnavailable", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a8a1714a85ad21a1c4814b260d2cd24dd", null ],
      [ "tiltfive::Error::kAlreadyConnected", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a24b0774645da8e1ae47649ae64ca88ea", null ],
      [ "tiltfive::Error::kNotConnected", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a32a54fa8629fe6e9cb3e265e959258d8", null ],
      [ "tiltfive::Error::kStringOverflow", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a06d34bffca9582c3dbc11cdea43e5be7", null ],
      [ "tiltfive::Error::kServiceIncompatible", "a00030.html#gga6debabd18fea86dba1be4fbb79687162a1ff7b6aeb3db444a14dae140348e5a25", null ],
      [ "tiltfive::Error::kPermissionDenied", "a00030.html#gga6debabd18fea86dba1be4fbb79687162adc0b458db7d0dd510aae0367dfafc4af", null ],
      [ "tiltfive::Error::kInvalidBuffer", "a00030.html#gga6debabd18fea86dba1be4fbb79687162ac63eb897493f14bd808056306dc2a845", null ],
      [ "tiltfive::Error::kInvalidGeometry", "a00030.html#gga6debabd18fea86dba1be4fbb79687162ac4283c91ae25b26dd77c5030baca028e", null ]
    ] ]
];
